'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _createForOfIteratorHelper2 = _interopRequireDefault(require("@babel/runtime/helpers/createForOfIteratorHelper"));
var _excluded = ["message"];
var _require = require('../store/RelayErrorTrie'),
  RelayFieldError = _require.RelayFieldError;
function handleFieldErrors(environment, errorResponseFields, shouldThrow) {
  var _iterator = (0, _createForOfIteratorHelper2["default"])(errorResponseFields),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var fieldError = _step.value;
      environment.relayFieldLogger(fieldError);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  if (shouldThrow) {
    throw new RelayFieldError("Relay: Unexpected response payload - this object includes an errors property in which you can access the underlying errors", errorResponseFields.map(function (event) {
      switch (event.kind) {
        case 'relay_field_payload.error':
          var _event$error = event.error,
            message = _event$error.message,
            displayError = (0, _objectWithoutPropertiesLoose2["default"])(_event$error, _excluded);
          return displayError;
        case 'missing_expected_data.throw':
          return {
            path: event.fieldPath.split('.')
          };
        case 'missing_expected_data.log':
          return {
            path: event.fieldPath.split('.')
          };
        case 'relay_resolver.error':
          return {
            path: event.fieldPath.split('.')
          };
        default:
          event.kind;
          throw new Error('Relay: Unexpected event kind');
      }
    }));
  }
}
function handleMissingRequiredFields(environment, missingRequiredFields) {
  switch (missingRequiredFields.action) {
    case 'THROW':
      {
        var _missingRequiredField = missingRequiredFields.field,
          path = _missingRequiredField.path,
          owner = _missingRequiredField.owner;
        environment.relayFieldLogger({
          kind: 'missing_required_field.throw',
          owner: owner,
          fieldPath: path
        });
        throw new Error("Relay: Missing @required value at path '".concat(path, "' in '").concat(owner, "'."));
      }
    case 'LOG':
      missingRequiredFields.fields.forEach(function (_ref) {
        var path = _ref.path,
          owner = _ref.owner;
        environment.relayFieldLogger({
          kind: 'missing_required_field.log',
          owner: owner,
          fieldPath: path
        });
      });
      break;
    default:
      {
        missingRequiredFields.action;
      }
  }
}
function handlePotentialSnapshotErrors(environment, missingRequiredFields, errorResponseFields, throwOnFieldError) {
  if (missingRequiredFields != null) {
    handleMissingRequiredFields(environment, missingRequiredFields);
  }
  if (errorResponseFields != null) {
    handleFieldErrors(environment, errorResponseFields, throwOnFieldError);
  }
}
module.exports = handlePotentialSnapshotErrors;